Multiaovbayes: Interactive panel Two-way ANOVA classic, non parametric and bayesian
Description
Interactive panel to visualize and develop two-way analysis of variance models, from the classical, non-parametric and Bayesian approach.
Usage
Multiaovbayes(dataset = FALSE)
Value
A shiny panel with the classical, non-parametric and Bayesian analyzes of variance, based on the specification of the dependent and independent variable of the data set provided in dataset, also provides a decision diagram that suggests which method is appropriate, based on the assumptions of the models.